/**
 * This file is part of pppBenchmark, a program accompanying
 * the paper: Abeel, T, Van de Peer Y, Saeys Y.  2009.  Towards a gold standard for promoter prediction evaluation. Bioinformatics. 25(12):i313-i320.
    * 
 * Copyright 2009 Thomas Abeel
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 */
package be.abeel.pppbenchmark;

public class Gene extends Site {

    @Override
    public boolean equals(Object o) {
        Gene g = (Gene) o;
        return g.forward == forward && super.equals(o);
    }
    @Override
    public int hashCode(){
        if(forward)
            return super.hashCode();
        else 
            return -super.hashCode();
    }

    private boolean forward;

    public Gene(int start, int end, boolean forward) {
        super(start, end);
        this.forward = forward;
    }

    public boolean isForward() {
        return forward;
    }

    public void setLowest(double score) {
        if (score > highestScore)
            highestScore = score;
    }

    double highestScore = -100000;

    public boolean nearStart(Prediction p, int distance) {
        if (forward) {
            if (Math.abs(p.start - this.start) <= distance)
                return true;
            if (Math.abs(p.end - this.start) <= distance)
                return true;
        } else {
            if (Math.abs(p.start - this.end) <= distance)
                return true;
            if (Math.abs(p.end - this.end) <= distance)
                return true;
        }
        return false;
    }

}